# ember-braintree-components

This addon includes Braintree's Drop-In Payment UI and Auth Connect button as Ember components.

## Installation

```bash
# From within your ember-cli project
ember install ember-braintree-components
```

## Usage

### Drop-In UI
```hbs
// template.hbs
<form>
  {{!-- Must be inside of a <form> --}}
  {{braintree-dropin
    token=braintreeClientToken
    onSubmit=(action 'submit')
  }}
  <button type="submit">Submit</button>
</form>
```

```js
// controller/component.js
actions: {
  submit(response) {
    // Do something with the nonce
    return this.get('ajax').post('[YOUR URL]', {
      data: {
        paymentNonce: response.nonce
      }
    });
  }
}
```

![drop-in ui](http://i64.tinypic.com/351blvm.png)

* `token`(required) - the token generated by your server
* `onReady` - action fired when the UI is ready
* `onSubmit` - action fired when the form is submitted (called with payment nonce)
* `onError` - action fired when an error occurred
* `options` - a hash containing additional options

[See the documentation](https://developers.braintreepayments.com/guides/drop-in/javascript/v2#options) for more information on these options.

### Braintree Auth Connect button

```hbs
// template.hbs
{{braintree-connect-button
  connectUrl=connectUrl
  onError=(action 'onError')
}}
```

<img src="https://s3-us-west-1.amazonaws.com/bt-partner-assets/connect-braintree.png" alt="Connect with Braintree" width="328" height="44">

#### Options

* `connectUrl`(required) - the url generated by your server
* `onError` - action fired when an error occurred
* `options` - a hash containing additional options

[See the documentation](https://developers.braintreepayments.com/guides/braintree-auth/client-side/javascript/v2) for more information on these options.
